PALM-meteo: palmmeteo_stdplugins/icon.py File Reference

PALM-meteo

Classes | Namespaces | Functions | Variables
icon.py File Reference

## Classes
class | palmmeteo_stdplugins.icon.IconPlugin

## Namespaces
namespace | palmmeteo_stdplugins
namespace | palmmeteo_stdplugins.icon

## Functions
def | palmmeteo_stdplugins.icon.lpad (var)
def | palmmeteo_stdplugins.icon.log_dstat_on (desc, delta)
def | palmmeteo_stdplugins.icon.log_dstat_off (desc, delta)
def | palmmeteo_stdplugins.icon.get_3dvar (f, varname)
def | palmmeteo_stdplugins.icon.assign_time (coll, key, value)

## Variables
| palmmeteo_stdplugins.icon.barom_pres = PalmPhysics.barom_lapse0_pres
| palmmeteo_stdplugins.icon.barom_gp = PalmPhysics.barom_lapse0_gp
| palmmeteo_stdplugins.icon.g = PalmPhysics.g
string | palmmeteo_stdplugins.icon.tstr0 = 'minutes since '